==> lpc55-pac-0.4.0.crate: lpc55-pac-0.4.0/src/gpio/b/b_.rs <==
#[doc = "Register `B_[%s]` reader"]
pub struct R(crate::R<B__SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<B__SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<B__SPEC>> for R {
    fn from(reader: crate::R<B__SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `B_[%s]` writer"]
pub struct W(crate::W<B__SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<B__SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<B__SPEC>> for W {
    fn from(writer: crate::W<B__SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `PBYTE` reader - Read: state of the pin PIOm_n, regardless of direction, masking, or alternate function, except that pins configured as analog I/O always read as 0. One register for each port pin. Supported pins depends on the specific device and package. Write: loads the pin's output bit. One register for each port pin. Supported pins depends on the specific device and package."]
pub struct PBYTE_R(crate::FieldReader<bool, bool>);
impl PBYTE_R {
    pub(crate) fn new(bits: bool) -> Self {
        PBYTE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PBYTE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `PBYTE` writer - Read: state of the pin PIOm_n, regardless of direction, masking, or alternate function, except that pins configured as analog I/O always read as 0. One register for each port pin. Supported pins depends on the specific device and package. Write: loads the pin's output bit. One register for each port pin. Supported pins depends on the specific device and package."]
pub struct PBYTE_W<'a> {
    w: &'a mut W,
}
impl<'a> PBYTE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u8 & 0x01);
        self.w
    }
}
impl R {
    #[doc = "Bit 0 - Read: state of the pin PIOm_n, regardless of direction, masking, or alternate function, except that pins configured as analog I/O always read as 0. One register for each port pin. Supported pins depends on the specific device and package. Write: loads the pin's output bit. One register for each port pin. Supported pins depends on the specific device and package."]
    #[inline(always)]
    pub fn pbyte(&self) -> PBYTE_R {
        PBYTE_R::new((self.bits & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bit 0 - Read: state of the pin PIOm_n, regardless of direction, masking, or alternate function, except that pins configured as analog I/O always read as 0. One register for each port pin. Supported pins depends on the specific device and package. Write: loads the pin's output bit. One register for each port pin. Supported pins depends on the specific device and package."]
    #[inline(always)]
    pub fn pbyte(&mut self) -> PBYTE_W {
        PBYTE_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u8) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Byte pin registers for all port GPIO pins\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [b_](index.html) module"]
pub struct B__SPEC;
impl crate::RegisterSpec for B__SPEC {
    type Ux = u8;
}
#[doc = "`read()` method returns [b_::R](R) reader structure"]
impl crate::Readable for B__SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [b_::W](W) writer structure"]
impl crate::Writable for B__SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets B_[%s]
to value 0"]
impl crate::Resettable for B__SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> lpc55-pac-0.5.0.crate: lpc55-pac-0.5.0/src/gpio/b/b_.rs <==
#[doc = "Register `B_[%s]` reader"]
pub struct R(crate::R<B__SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<B__SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<B__SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<B__SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `B_[%s]` writer"]
pub struct W(crate::W<B__SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<B__SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<B__SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<B__SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `PBYTE` reader - Read: state of the pin PIOm_n, regardless of direction, masking, or alternate function, except that pins configured as analog I/O always read as 0. One register for each port pin. Supported pins depends on the specific device and package. Write: loads the pin's output bit. One register for each port pin. Supported pins depends on the specific device and package."]
pub struct PBYTE_R(crate::FieldReader<bool, bool>);
impl PBYTE_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        PBYTE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PBYTE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `PBYTE` writer - Read: state of the pin PIOm_n, regardless of direction, masking, or alternate function, except that pins configured as analog I/O always read as 0. One register for each port pin. Supported pins depends on the specific device and package. Write: loads the pin's output bit. One register for each port pin. Supported pins depends on the specific device and package."]
pub struct PBYTE_W<'a> {
    w: &'a mut W,
}
impl<'a> PBYTE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u8 & 0x01);
        self.w
    }
}
impl R {
    #[doc = "Bit 0 - Read: state of the pin PIOm_n, regardless of direction, masking, or alternate function, except that pins configured as analog I/O always read as 0. One register for each port pin. Supported pins depends on the specific device and package. Write: loads the pin's output bit. One register for each port pin. Supported pins depends on the specific device and package."]
    #[inline(always)]
    pub fn pbyte(&self) -> PBYTE_R {
        PBYTE_R::new((self.bits & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bit 0 - Read: state of the pin PIOm_n, regardless of direction, masking, or alternate function, except that pins configured as analog I/O always read as 0. One register for each port pin. Supported pins depends on the specific device and package. Write: loads the pin's output bit. One register for each port pin. Supported pins depends on the specific device and package."]
    #[inline(always)]
    pub fn pbyte(&mut self) -> PBYTE_W {
        PBYTE_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u8) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Byte pin registers for all port GPIO pins\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [b_](index.html) module"]
pub struct B__SPEC;
impl crate::RegisterSpec for B__SPEC {
    type Ux = u8;
}
#[doc = "`read()` method returns [b_::R](R) reader structure"]
impl crate::Readable for B__SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [b_::W](W) writer structure"]
impl crate::Writable for B__SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets B_[%s]
to value 0"]
impl crate::Resettable for B__SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
